package com.unis.visualization.modular.MonitorAI.mapper;


import java.util.List;
import java.util.Map;

public interface MonitorAIMapper {
     Integer selectMonitorCount();


     Integer selectFaultMonitorCount();

     Integer selectMonitorProportion();

    List<Map<String,Object>> selectMonitorInsideCount();

    List<Map<String, Object>> selectCityMonitorCount();

    List<Map<String, Object>> selectKqMonitorCount();

    List<Map<String, Object>> selectException();

    List<Map<String, Object>> selectMonitorWarningCount();

    List<Map<String, Object>> selectMonitorStatistics();

    List<Map<String, Object>> selectEmergencyBusinessStatistics();

    List<Map<String, Object>> selectCityEmergencyBusinessStatistics();

    List<Map<String, Object>> selectDPVSMETStatistics();

    List<Map<String, Object>> selectCityDailySupplyCapacity();

    List<Map<String, Object>> selectDailyInventoryCapacity();

    List<Map<String, Object>> selectDeliveryCapability();
}
